package DD::Dummy;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2019-08-08'; # DATE
our $DIST = 'DD'; # DIST
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: A dummy module to pull DD

__END__

=pod

=encoding UTF-8

=head1 NAME

DD::Dummy - A dummy module to pull DD

=head1 VERSION

This document describes version 0.004 of DD::Dummy (from Perl distribution DD), released on 2019-08-08.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/DD>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-DD>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=DD>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<DD>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
